@@ -175,7 +175,7 @@ class InvalidParameterValue(Invalid):
 
 
 class InvalidUUID(Invalid):
-    message = _("Expected a uuid but received %(uuid)s.")
+    message = _("%(uuid)s is not a valid uuid.")
 
 
 class InvalidDriverMode(Invalid):
@@ -546,6 +546,10 @@ class ShareNotFound(NotFound):
     message = _("Share %(share_id)s could not be found.")
 
 
+class ShareInstanceNotFound(NotFound):
+    message = _("Share instance %(share_instance_id)s could not be found.")
+
+
 class ShareSnapshotNotFound(NotFound):
     message = _("Snapshot %(snapshot_id)s could not be found.")
 
@@ -793,6 +797,11 @@ class NetAppException(ManilaException):
     message = _("Exception due to NetApp failure.")
 
 
+class NetAppBusyAggregateForFlexGroupException(ManilaException):
+    message = _("Exception due to an aggregate being busy while trying to "
+                "provision the FlexGroup.")
+
+
 class VserverNotFound(NetAppException):
     message = _("Vserver %(vserver)s not found.")
 
