@@ -276,6 +276,11 @@ class CephFSDriver(driver.ExecuteMixin, driver.GaneshaMixin,
                     'qos': 'False',
                     'reserved_percentage': self.configuration.safe_get(
                         'reserved_share_percentage'),
+                    'reserved_snapshot_percentage':
+                        self.configuration.safe_get(
+                            'reserved_share_from_snapshot_percentage') or
+                        self.configuration.safe_get(
+                            'reserved_share_percentage'),
                     'dedupe': [False],
                     'compression': [False],
                     'thin_provisioning': [False]
@@ -601,7 +606,7 @@ class CephFSDriver(driver.ExecuteMixin, driver.GaneshaMixin,
         rados_command(self.rados_client, "fs subvolumegroup create", argdict)
 
     def delete_share_group(self, context, sg_dict, share_server=None):
-        # create a FS group
+        # delete a FS group
         LOG.debug("[%(be)s]: delete_share_group: share_group=%(id)s.",
                   {"be": self.backend_name, "id": sg_dict['id']})
 
@@ -641,16 +646,10 @@ class CephFSDriver(driver.ExecuteMixin, driver.GaneshaMixin,
                   {"be": self.backend_name, "id": snap_dict['share_group_id'],
                    "sn": snap_dict["id"]})
 
-        argdict = {
-            "vol_name": self.volname,
-            "group_name": snap_dict["share_group_id"],
-            "snap_name": snap_dict["id"]
-        }
-
-        rados_command(
-            self.rados_client, "fs subvolumegroup snapshot create", argdict)
-
-        return None, []
+        msg = _("Share group snapshot feature is no longer supported in "
+                "mainline CephFS (existing group snapshots can still be "
+                "listed and deleted).")
+        raise exception.ShareBackendException(msg=msg)
 
     def _get_clone_status(self, share):
         """Check the status of a newly cloned share."""
@@ -988,16 +987,9 @@ class NFSProtocolHelper(ganesha.GaneshaNASHelper2):
     def get_export_locations(self, share, subvolume_path):
         export_locations = []
         for export_ip in self.export_ips:
-            # Try to escape the export ip. If it fails, means that the
-            # `cephfs_ganesha_server_ip` wasn't possibly set and the used
-            # address is the hostname
-            try:
-                server_address = driver_helpers.escaped_address(export_ip)
-            except ValueError:
-                server_address = export_ip
-
             export_path = "{server_address}:{mount_path}".format(
-                server_address=server_address, mount_path=subvolume_path)
+                server_address=driver_helpers.escaped_address(export_ip),
+                mount_path=subvolume_path)
 
             LOG.info("Calculated export path for share %(id)s: %(epath)s",
                      {"id": share['id'], "epath": export_path})
