@@ -50,14 +50,11 @@ LOG = log.getLogger(__name__)
 
 POWERMAX_OPTS = [
     cfg.StrOpt('powermax_server_container',
-               deprecated_name='vmax_server_container',
                help='Data mover to host the NAS server.'),
     cfg.ListOpt('powermax_share_data_pools',
-                deprecated_name='vmax_share_data_pools',
                 help='Comma separated list of pools that can be used to '
                      'persist share data.'),
     cfg.ListOpt('powermax_ethernet_ports',
-                deprecated_name='vmax_ethernet_ports',
                 help='Comma separated list of ports that can be used for '
                      'share server interfaces. Members of the list '
                      'can be Unix-style glob expressions.')
@@ -84,9 +81,14 @@ class PowerMaxStorageConnection(driver.StorageConnection):
         self.manager = None
         self.pool_conf = None
         self.reserved_percentage = None
+        self.reserved_snapshot_percentage = None
         self.driver_handles_share_servers = True
         self.port_conf = None
         self.ipv6_implemented = True
+        self.dhss_mandatory_security_service_association = {
+            'nfs': None,
+            'cifs': ['active_directory', ]
+        }
 
     def create_share(self, context, share, share_server=None):
         """Create a share and export it based on protocol used."""
@@ -593,6 +595,11 @@ class PowerMaxStorageConnection(driver.StorageConnection):
         if self.reserved_percentage is None:
             self.reserved_percentage = 0
 
+        self.reserved_snapshot_percentage = config.safe_get(
+            'reserved_share_from_snapshot_percentage')
+        if self.reserved_snapshot_percentage is None:
+            self.reserved_snapshot_percentage = self.reserved_percentage
+
         self.manager = manager.StorageObjectManager(config)
         self.port_conf = config.safe_get('powermax_ethernet_ports')
 
@@ -641,6 +648,8 @@ class PowerMaxStorageConnection(driver.StorageConnection):
                         enas_utils.mb_to_gb(total_size - used_size),
                     'qos': False,
                     'reserved_percentage': self.reserved_percentage,
+                    'reserved_snapshot_percentage':
+                        self.reserved_snapshot_percentage,
                     'snapshot_support': True,
                     'create_share_from_snapshot_support': True,
                     'revert_to_snapshot_support': False,
