@@ -35,6 +35,13 @@ class NetAppCmodeMultiSvmShareDriver(driver.ShareDriver):
             True, *args, **kwargs)
         self.library = lib_multi_svm.NetAppCmodeMultiSVMFileStorageLibrary(
             self.DRIVER_NAME, **kwargs)
+        # NetApp driver supports updating security service for in use share
+        # networks.
+        self.security_service_update_support = True
+        self.dhss_mandatory_security_service_association = {
+            'nfs': None,
+            'cifs': ['active_directory', ]
+        }
 
     def do_setup(self, context):
         self.library.do_setup(context)
@@ -106,13 +113,13 @@ class NetAppCmodeMultiSvmShareDriver(driver.ShareDriver):
 
     def _update_share_stats(self, data=None):
         data = self.library.get_share_stats(
-            filter_function=self.get_filter_function(),
+            get_filter_function=self.get_filter_function,
             goodness_function=self.get_goodness_function())
         super(NetAppCmodeMultiSvmShareDriver, self)._update_share_stats(
             data=data)
 
-    def get_default_filter_function(self):
-        return self.library.get_default_filter_function()
+    def get_default_filter_function(self, pool=None):
+        return self.library.get_default_filter_function(pool=pool)
 
     def get_default_goodness_function(self):
         return self.library.get_default_goodness_function()
@@ -286,3 +293,69 @@ class NetAppCmodeMultiSvmShareDriver(driver.ShareDriver):
 
     def get_share_status(self, share_instance, share_server=None):
         return self.library.get_share_status(share_instance, share_server)
+
+    def share_server_migration_check_compatibility(
+            self, context, share_server, dest_host, old_share_network,
+            new_share_network, shares_request_spec):
+
+        return self.library.share_server_migration_check_compatibility(
+            context, share_server, dest_host, old_share_network,
+            new_share_network, shares_request_spec)
+
+    def share_server_migration_start(self, context, src_share_server,
+                                     dest_share_server, shares, snapshots):
+        return self.library.share_server_migration_start(
+            context, src_share_server, dest_share_server, shares, snapshots)
+
+    def share_server_migration_continue(self, context, src_share_server,
+                                        dest_share_server, shares, snapshots):
+        return self.library.share_server_migration_continue(
+            context, src_share_server, dest_share_server, shares, snapshots)
+
+    def share_server_migration_complete(self, context, src_share_server,
+                                        dest_share_server, shares, snapshots,
+                                        new_network_info):
+        return self.library.share_server_migration_complete(
+            context, src_share_server, dest_share_server, shares, snapshots,
+            new_network_info)
+
+    def share_server_migration_cancel(self, context, src_share_server,
+                                      dest_share_server, shares, snapshots):
+        self.library.share_server_migration_cancel(
+            context, src_share_server, dest_share_server, shares, snapshots)
+
+    def choose_share_server_compatible_with_share(self, context, share_servers,
+                                                  share, snapshot=None,
+                                                  share_group=None):
+        return self.library.choose_share_server_compatible_with_share(
+            context, share_servers, share, snapshot=snapshot,
+            share_group=share_group)
+
+    def choose_share_server_compatible_with_share_group(
+            self, context, share_servers, share_group_ref,
+            share_group_snapshot=None):
+        return self.library.choose_share_server_compatible_with_share_group(
+            context, share_servers, share_group_ref,
+            share_group_snapshot=share_group_snapshot)
+
+    def share_server_migration_get_progress(self, context, src_share_server,
+                                            dest_share_server, shares,
+                                            snapshots):
+        return self.library.share_server_migration_get_progress(
+            context, src_share_server, dest_share_server, shares, snapshots)
+
+    def update_share_server_security_service(
+            self, context, share_server, network_info, share_instances,
+            share_instance_rules, new_security_service,
+            current_security_service=None):
+        return self.library.update_share_server_security_service(
+            context, share_server, network_info, new_security_service,
+            current_security_service=current_security_service)
+
+    def check_update_share_server_security_service(
+            self, context, share_server, network_info, share_instances,
+            share_instance_rules, new_security_service,
+            current_security_service=None):
+        return self.library.check_update_share_server_security_service(
+            context, share_server, network_info, new_security_service,
+            current_security_service=current_security_service)
