@@ -36,7 +36,7 @@ ZFSSA_OPTS = [
     cfg.StrOpt('zfssa_auth_user',
                help='ZFSSA management authorized username.'),
     cfg.StrOpt('zfssa_auth_password',
-               help='ZFSSA management authorized userpassword.'),
+               help='ZFSSA management authorized user\'s password.'),
     cfg.StrOpt('zfssa_pool',
                help='ZFSSA storage pool name.'),
     cfg.StrOpt('zfssa_project',
@@ -138,7 +138,7 @@ class ZFSSAShareDriver(driver.ShareDriver):
         self.zfssa = factory_zfssa()
         self.zfssa.set_host(lcfg.zfssa_host, timeout=lcfg.zfssa_rest_timeout)
         creds = '%s:%s' % (lcfg.zfssa_auth_user, lcfg.zfssa_auth_password)
-        auth_str = base64.encodestring(six.b(creds))[:-1]
+        auth_str = base64.encodebytes(six.b(creds))[:-1]
         self.zfssa.login(auth_str)
         if lcfg.zfssa_nas_mountpoint == '':
             self.mountpoint += lcfg.zfssa_project
@@ -242,7 +242,7 @@ class ZFSSAShareDriver(driver.ShareDriver):
                                    snapshot['id'])
 
     def create_share_from_snapshot(self, context, share, snapshot,
-                                   share_server=None):
+                                   share_server=None, parent_share=None):
         """Create a share from a snapshot - clone a snapshot."""
         lcfg = self.configuration
         LOG.debug("ZFSSAShareDriver.create_share_from_snapshot: clone=%s",
