@@ -40,7 +40,10 @@ fake_share_server_list = {
             'project_id': 'fake_project_id',
             'id': 'fake_server_id',
             'is_auto_deletable': False,
-            'identifier': 'fake_id'
+            'task_state': None,
+            'source_share_server_id': None,
+            'identifier': 'fake_id',
+            'security_service_update_support': False
         },
         {
             'status': constants.STATUS_ERROR,
@@ -52,7 +55,11 @@ fake_share_server_list = {
             'project_id': 'fake_project_id_2',
             'id': 'fake_server_id_2',
             'is_auto_deletable': True,
-            'identifier': 'fake_id_2'
+            'task_state': None,
+            'source_share_server_id': None,
+            'identifier': 'fake_id_2',
+            'security_service_update_support': False
+
         },
     ]
 }
@@ -88,7 +95,10 @@ fake_share_server_get_result = {
             'fake_key_2': 'fake_value_2',
         },
         'is_auto_deletable': False,
-        'identifier': 'fake_id'
+        'task_state': None,
+        'source_share_server_id': None,
+        'identifier': 'fake_id',
+        'security_service_update_support': False
     }
 }
 
@@ -122,7 +132,11 @@ class FakeShareServer(object):
         self.project_id = 'fake_project_id'
         self.identifier = kwargs.get('identifier', 'fake_id')
         self.is_auto_deletable = kwargs.get('is_auto_deletable', False)
+        self.task_state = kwargs.get('task_state')
+        self.source_share_server_id = kwargs.get('source_share_server_id')
         self.backend_details = share_server_backend_details
+        self.security_service_update_support = kwargs.get(
+            'security_service_update_support', False)
 
     def __getitem__(self, item):
         return getattr(self, item)
@@ -138,8 +152,10 @@ def fake_share_server_get_all():
                             'share_network_id': 'fake_sn_id_2',
                             },
                         identifier='fake_id_2',
+                        task_state=None,
                         is_auto_deletable=True,
-                        status=constants.STATUS_ERROR)
+                        status=constants.STATUS_ERROR,
+                        security_service_update_support=False)
     ]
     return fake_share_servers
 
