@@ -14,19 +14,20 @@
 # under the License.
 
 import code
+import io
 import readline
 import sys
 from unittest import mock
 
 import ddt
 from oslo_config import cfg
-import six
 
 from manila.cmd import manage as manila_manage
 from manila import context
 from manila import db
 from manila.db import migration
 from manila import test
+from manila import utils
 from manila import version
 
 CONF = cfg.CONF
@@ -46,6 +47,7 @@ class ManilaCmdManageTestCase(test.TestCase):
         self.get_log_cmds = manila_manage.GetLogCommands()
         self.service_cmds = manila_manage.ServiceCommands()
         self.share_cmds = manila_manage.ShareCommands()
+        self.server_cmds = manila_manage.ShareServerCommands()
 
     @mock.patch.object(manila_manage.ShellCommands, 'run', mock.Mock())
     def test_shell_commands_bpython(self):
@@ -67,7 +69,7 @@ class ManilaCmdManageTestCase(test.TestCase):
         try:
             import bpython
         except ImportError as e:
-            self.skipTest(six.text_type(e))
+            self.skipTest(str(e))
         self.mock_object(bpython, 'embed')
         self.shell_commands.run(**kwargs)
         bpython.embed.assert_called_once_with()
@@ -77,7 +79,7 @@ class ManilaCmdManageTestCase(test.TestCase):
             import bpython
             import IPython
         except ImportError as e:
-            self.skipTest(six.text_type(e))
+            self.skipTest(str(e))
         self.mock_object(bpython, 'embed',
                          mock.Mock(side_effect=ImportError()))
         self.mock_object(IPython, 'embed')
@@ -90,7 +92,7 @@ class ManilaCmdManageTestCase(test.TestCase):
         try:
             import bpython
         except ImportError as e:
-            self.skipTest(six.text_type(e))
+            self.skipTest(str(e))
         self.mock_object(bpython, 'embed')
 
         self.shell_commands.run()
@@ -101,7 +103,7 @@ class ManilaCmdManageTestCase(test.TestCase):
         try:
             import IPython
         except ImportError as e:
-            self.skipTest(six.text_type(e))
+            self.skipTest(str(e))
         self.mock_object(IPython, 'embed')
 
         self.shell_commands.run(shell='ipython')
@@ -116,7 +118,7 @@ class ManilaCmdManageTestCase(test.TestCase):
                 setattr(IPython.Shell, 'IPShell',
                         mock.Mock(side_effect=ImportError()))
         except ImportError as e:
-            self.skipTest(six.text_type(e))
+            self.skipTest(str(e))
         self.mock_object(IPython, 'embed',
                          mock.Mock(side_effect=ImportError()))
         self.mock_object(readline, 'parse_and_bind')
@@ -147,7 +149,7 @@ class ManilaCmdManageTestCase(test.TestCase):
         readline.parse_and_bind.assert_called_once_with("tab:complete")
         code.interact.assert_called_once_with()
 
-    @mock.patch('six.moves.builtins.print')
+    @mock.patch('builtins.print')
     def test_list(self, print_mock):
         serv_1 = {
             'host': 'fake_host1',
@@ -169,7 +171,7 @@ class ManilaCmdManageTestCase(test.TestCase):
             mock.call(u'host                     \tzone           '),
             mock.call('fake_host1               \tavail_zone1    ')])
 
-    @mock.patch('six.moves.builtins.print')
+    @mock.patch('builtins.print')
     def test_list_zone_is_none(self, print_mock):
         serv_1 = {
             'host': 'fake_host1',
@@ -220,7 +222,7 @@ class ManilaCmdManageTestCase(test.TestCase):
     def test_version_commands_list(self):
         self.mock_object(version, 'version_string',
                          mock.Mock(return_value='123'))
-        with mock.patch('sys.stdout', new=six.StringIO()) as fake_out:
+        with mock.patch('sys.stdout', new=io.StringIO()) as fake_out:
             self.version_commands.list()
         version.version_string.assert_called_once_with()
         self.assertEqual('123\n', fake_out.getvalue())
@@ -228,13 +230,13 @@ class ManilaCmdManageTestCase(test.TestCase):
     def test_version_commands_call(self):
         self.mock_object(version, 'version_string',
                          mock.Mock(return_value='123'))
-        with mock.patch('sys.stdout', new=six.StringIO()) as fake_out:
+        with mock.patch('sys.stdout', new=io.StringIO()) as fake_out:
             self.version_commands()
         version.version_string.assert_called_once_with()
         self.assertEqual('123\n', fake_out.getvalue())
 
     def test_get_log_commands_no_errors(self):
-        with mock.patch('sys.stdout', new=six.StringIO()) as fake_out:
+        with mock.patch('sys.stdout', new=io.StringIO()) as fake_out:
             CONF.set_override('log_dir', None)
             expected_out = 'No errors in logfiles!\n'
 
@@ -242,14 +244,14 @@ class ManilaCmdManageTestCase(test.TestCase):
 
             self.assertEqual(expected_out, fake_out.getvalue())
 
-    @mock.patch('six.moves.builtins.open')
+    @mock.patch('builtins.open')
     @mock.patch('os.listdir')
     def test_get_log_commands_errors(self, listdir, open):
         CONF.set_override('log_dir', 'fake-dir')
         listdir.return_value = ['fake-error.log']
 
-        with mock.patch('sys.stdout', new=six.StringIO()) as fake_out:
-            open.return_value = six.StringIO(
+        with mock.patch('sys.stdout', new=io.StringIO()) as fake_out:
+            open.return_value = io.StringIO(
                 '[ ERROR ] fake-error-message')
             expected_out = ('fake-dir/fake-error.log:-\n'
                             'Line 1 : [ ERROR ] fake-error-message\n')
@@ -259,7 +261,7 @@ class ManilaCmdManageTestCase(test.TestCase):
             open.assert_called_once_with('fake-dir/fake-error.log', 'r')
             listdir.assert_called_once_with(CONF.log_dir)
 
-    @mock.patch('six.moves.builtins.open')
+    @mock.patch('builtins.open')
     @mock.patch('os.path.exists')
     def test_get_log_commands_syslog_no_log_file(self, path_exists, open):
         path_exists.return_value = False
@@ -282,7 +284,7 @@ class ManilaCmdManageTestCase(test.TestCase):
                    'disabled': False}
         service_get_all.return_value = [service]
         service_is_up.return_value = True
-        with mock.patch('sys.stdout', new=six.StringIO()) as fake_out:
+        with mock.patch('sys.stdout', new=io.StringIO()) as fake_out:
             format = "%-16s %-36s %-16s %-10s %-5s %-10s"
             print_format = format % ('Binary',
                                      'Host',
@@ -303,6 +305,39 @@ class ManilaCmdManageTestCase(test.TestCase):
             service_get_all.assert_called_with(ctxt)
             service_is_up.assert_called_with(service)
 
+    @ddt.data(True, False)
+    def test_service_commands_cleanup(self, service_is_up):
+        ctxt = context.RequestContext('fake-user', 'fake-project')
+        self.mock_object(context, 'get_admin_context',
+                         mock.Mock(return_value=ctxt))
+        service = {'id': 17,
+                   'binary': 'manila-binary',
+                   'host': 'fake-host.fake-domain',
+                   'availability_zone': {'name': 'fake-zone'},
+                   'updated_at': '2020-06-17 07:22:33',
+                   'disabled': False}
+        self.mock_object(db, 'service_get_all',
+                         mock.Mock(return_value=[service]))
+        self.mock_object(db, 'service_destroy')
+        self.mock_object(utils, 'service_is_up',
+                         mock.Mock(return_value=service_is_up))
+
+        with mock.patch('sys.stdout', new=io.StringIO()) as fake_out:
+            if not service_is_up:
+                expected_out = "Cleaned up service %s" % service['host']
+            else:
+                expected_out = ''
+            self.service_cmds.cleanup()
+
+            self.assertEqual(expected_out, fake_out.getvalue().strip())
+            context.get_admin_context.assert_called_with()
+            db.service_get_all.assert_called_with(ctxt)
+            utils.service_is_up.assert_called_with(service)
+            if not service_is_up:
+                db.service_destroy.assert_called_with(ctxt, service['id'])
+            else:
+                self.assertFalse(db.service_destroy.called)
+
     def test_methods_of(self):
         obj = type('Fake', (object,),
                    {name: lambda: 'fake_' for name in ('_a', 'b', 'c')})
@@ -370,13 +405,13 @@ class ManilaCmdManageTestCase(test.TestCase):
     def test_share_update_host_fail_validation(self, current_host, new_host):
         self.mock_object(context, 'get_admin_context',
                          mock.Mock(return_value='admin_ctxt'))
-        self.mock_object(db, 'share_instances_host_update')
+        self.mock_object(db, 'share_resources_host_update')
 
         self.assertRaises(SystemExit,
                           self.share_cmds.update_host,
                           current_host, new_host)
 
-        self.assertFalse(db.share_instances_host_update.called)
+        self.assertFalse(db.share_resources_host_update.called)
 
     @ddt.data({'current_host': 'controller-0@fancystore01#pool100',
                'new_host': 'controller-0@fancystore02#pool0'},
@@ -388,17 +423,59 @@ class ManilaCmdManageTestCase(test.TestCase):
                'new_host': 'controller-1@fancystore02', 'force': True})
     @ddt.unpack
     def test_share_update_host(self, current_host, new_host, force=False):
+        db_op = {'instances': 3, 'groups': 4, 'servers': 2}
         self.mock_object(context, 'get_admin_context',
                          mock.Mock(return_value='admin_ctxt'))
-        self.mock_object(db, 'share_instances_host_update',
-                         mock.Mock(return_value=20))
+        self.mock_object(db, 'share_resources_host_update',
+                         mock.Mock(return_value=db_op))
 
-        with mock.patch('sys.stdout', new=six.StringIO()) as intercepted_op:
+        with mock.patch('sys.stdout', new=io.StringIO()) as intercepted_op:
             self.share_cmds.update_host(current_host, new_host, force)
 
-        expected_op = ("Updated host of 20 share instances on "
-                       "%(chost)s to %(nhost)s." %
+        expected_op = ("Updated host of 3 share instances, 4 share groups and "
+                       "2 share servers on %(chost)s to %(nhost)s." %
                        {'chost': current_host, 'nhost': new_host})
         self.assertEqual(expected_op, intercepted_op.getvalue().strip())
-        db.share_instances_host_update.assert_called_once_with(
+        db.share_resources_host_update.assert_called_once_with(
             'admin_ctxt', current_host, new_host)
+
+    def test_share_server_update_capability(self):
+        self.mock_object(context, 'get_admin_context',
+                         mock.Mock(return_value='admin_ctxt'))
+        self.mock_object(db, 'share_servers_update')
+        share_servers = 'server_id_a,server_id_b'
+        share_server_list = [server.strip()
+                             for server in share_servers.split(",")]
+        capability = 'security_service_update_support'
+        values_to_update = {
+            capability: True
+        }
+
+        with mock.patch('sys.stdout', new=io.StringIO()) as output:
+            self.server_cmds.update_share_server_capabilities(
+                share_servers, capability, True)
+
+        expected_op = ("The capability(ies) %(cap)s of the following share "
+                       "server(s) %(servers)s was(were) updated to "
+                       "%(value)s.") % {
+            'cap': [capability],
+            'servers': share_server_list,
+            'value': True,
+        }
+
+        self.assertEqual(expected_op, output.getvalue().strip())
+        db.share_servers_update.assert_called_once_with(
+            'admin_ctxt', share_server_list, values_to_update)
+
+    def test_share_server_update_capability_not_supported(self):
+        share_servers = 'server_id_a'
+        capabilities = 'invalid_capability'
+
+        exit = self.assertRaises(
+            SystemExit,
+            self.server_cmds.update_share_server_capabilities,
+            share_servers,
+            capabilities,
+            True)
+
+        self.assertEqual(1, exit.code)
