@@ -13,8 +13,10 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-import mock
+from unittest import mock
+
 from oslo_config import cfg
+from oslo_utils import units
 import six
 
 from manila import context
@@ -95,7 +97,9 @@ class QuobyteShareDriverTestCase(test.TestCase):
         self.fake_conf = config.Configuration(None)
         self._driver = quobyte.QuobyteShareDriver(configuration=self.fake_conf)
         self._driver.rpc = mock.Mock()
-        self.share = fake_share.fake_share(share_proto='NFS')
+        self.share = fake_share.fake_share(
+            share_proto='NFS',
+            export_location='fake_location:/quobyte/fake_share')
         self.access = fake_share.fake_access()
 
     @mock.patch('manila.share.drivers.quobyte.jsonrpc.JsonRpc', mock.Mock())
@@ -114,7 +118,8 @@ class QuobyteShareDriverTestCase(test.TestCase):
         self.assertRaises(exception.QBException,
                           self._driver.do_setup, self._context)
 
-    def test_create_share_new_volume(self):
+    @mock.patch.object(quobyte.QuobyteShareDriver, "_resize_share")
+    def test_create_share_new_volume(self, qb_resize_mock):
         self._driver.rpc.call = mock.Mock(wraps=fake_rpc_handler)
 
         result = self._driver.create_share(self._context, self.share)
@@ -130,12 +135,15 @@ class QuobyteShareDriverTestCase(test.TestCase):
             )),
             mock.call('exportVolume',
                       dict(protocol='NFS', volume_uuid='voluuid'))])
+        qb_resize_mock.assert_called_once_with(self.share, self.share['size'])
 
-    def test_create_share_existing_volume(self):
+    @mock.patch.object(quobyte.QuobyteShareDriver, "_resize_share")
+    def test_create_share_existing_volume(self, qb_resize_mock):
         self._driver.rpc.call = mock.Mock(wraps=fake_rpc_handler)
 
-        self._driver.create_share(self._context, self.share)
+        result = self._driver.create_share(self._context, self.share)
 
+        self.assertEqual(self.share['export_location'], result)
         resolv_params = {'tenant_domain': 'fake_project_uuid',
                          'volume_name': 'fakename'}
         sett_params = {'tenant': {'tenant_id': 'fake_project_uuid'}}
@@ -153,6 +161,7 @@ class QuobyteShareDriverTestCase(test.TestCase):
             mock.call('createVolume', create_params),
             mock.call('exportVolume', dict(protocol='NFS',
                                            volume_uuid='voluuid'))])
+        qb_resize_mock.assert_called_once_with(self.share, self.share['size'])
 
     def test_create_share_wrong_protocol(self):
         share = {'share_proto': 'WRONG_PROTOCOL'}
@@ -334,7 +343,8 @@ class QuobyteShareDriverTestCase(test.TestCase):
                  driver_version=self._driver.DRIVER_VERSION,
                  total_capacity_gb=42,
                  free_capacity_gb=23,
-                 reserved_percentage=0))
+                 reserved_percentage=0,
+                 reserved_snapshot_percentage=0))
 
     def test_get_capacities_gb(self):
         capval = 42115548133
@@ -411,24 +421,31 @@ class QuobyteShareDriverTestCase(test.TestCase):
         mock_qsd_resize_share.assert_called_once_with(share=self.share,
                                                       new_size=2)
 
-    def test_resize_share(self):
+    @mock.patch.object(quobyte.QuobyteShareDriver, "_resolve_volume_name",
+                       return_value="fake_volume_uuid")
+    def test_resize_share(self, mock_qb_resolv):
         self._driver.rpc.call = mock.Mock(wraps=fake_rpc_handler)
+        manila_size = 7
+        newsize_bytes = manila_size * units.Gi
 
-        self._driver._resize_share(share=self.share, new_size=7)
+        self._driver._resize_share(share=self.share, new_size=manila_size)
 
         exp_params = {
             "quotas": [{
                 "consumer": [{
                     "type": "VOLUME",
-                    "identifier": self.share["name"],
+                    "identifier": "fake_volume_uuid",
+                    "tenant_id": self.share["project_id"]
                 }],
                 "limits": [{
                     "type": "LOGICAL_DISK_SPACE",
-                    "value": 7,
+                    "value": newsize_bytes,
                 }],
             }]}
         self._driver.rpc.call.assert_has_calls([
             mock.call('setQuota', exp_params)])
+        mock_qb_resolv.assert_called_once_with(self.share['name'],
+                                               self.share['project_id'])
 
     @mock.patch.object(quobyte.QuobyteShareDriver,
                        "_resolve_volume_name",
