@@ -18,9 +18,9 @@
 
 import os
 import time
+from unittest import mock
 
 import ddt
-import mock
 from oslo_concurrency import processutils
 from oslo_config import cfg
 from six import moves
@@ -492,13 +492,13 @@ class GenericShareDriverTestCase(test.TestCase):
     def test_add_mount_permanently(self):
         self.mock_object(self._driver, '_ssh_exec')
         self._driver._add_mount_permanently(self.share.id, self.server)
-        self._driver._ssh_exec.has_calls(
+        self._driver._ssh_exec.assert_has_calls([
             mock.call(
                 self.server,
                 ['grep', self.share.id, const.MOUNT_FILE_TEMP,
                  '|', 'sudo', 'tee', '-a', const.MOUNT_FILE]),
             mock.call(self.server, ['sudo', 'mount', '-a'])
-        )
+        ])
 
     def test_add_mount_permanently_raise_error_on_add(self):
         self.mock_object(
@@ -1332,7 +1332,8 @@ class GenericShareDriverTestCase(test.TestCase):
             'qos', 'driver_version', 'share_backend_name',
             'free_capacity_gb', 'total_capacity_gb',
             'driver_handles_share_servers',
-            'reserved_percentage', 'vendor_name', 'storage_protocol',
+            'reserved_percentage', 'reserved_snapshot_percentage',
+            'vendor_name', 'storage_protocol',
         ]
 
         result = self._driver.get_share_stats(True)
