@@ -92,6 +92,7 @@ class LVMShareDriverTestCase(test.TestCase):
         CONF.set_default('lvm_share_export_ips', ['10.0.0.1', '10.0.0.2'])
         CONF.set_default('driver_handles_share_servers', False)
         CONF.set_default('reserved_share_percentage', 50)
+        CONF.set_default('reserved_share_from_snapshot_percentage', 30)
 
         self._helper_cifs = mock.Mock()
         self._helper_nfs = mock.Mock()
@@ -248,9 +249,12 @@ class LVMShareDriverTestCase(test.TestCase):
                           self._driver._deallocate_container,
                           self.share['name'])
 
-    def test_deallocate_container_not_found_error(self):
+    @ddt.data(
+        'Logical volume "fake/fake-volume" not found\n',
+        'Failed to find logical volume "fake/fake-volume"\n')
+    def test_deallocate_container_not_found_error(self, error_msg):
         def _fake_exec(*args, **kwargs):
-            raise exception.ProcessExecutionError(stderr="not found")
+            raise exception.ProcessExecutionError(stderr=error_msg)
 
         self.mock_object(self._driver, '_try_execute', _fake_exec)
         self._driver._deallocate_container(self.share['name'])
@@ -268,6 +272,22 @@ class LVMShareDriverTestCase(test.TestCase):
                              self._driver.get_share_stats(refresh=True))
         self._driver._update_share_stats.assert_called_once_with()
 
+    def test__unmount_device_not_mounted(self):
+        def exec_runner(*ignore_args, **ignore_kwargs):
+            umount_msg = (
+                "umount: /opt/stack/data/manila/mnt/share-fake-share: not "
+                "mounted.\n"
+            )
+            raise exception.ProcessExecutionError(stderr=umount_msg)
+        self._os.path.exists.return_value = True
+        mount_path = self._get_mount_path(self.share)
+        expected_exec = "umount -f %s" % (mount_path)
+        fake_utils.fake_execute_set_repliers([(expected_exec, exec_runner)])
+
+        self._driver._unmount_device(self.share, raise_if_missing=False)
+
+        self._os.path.exists.assert_called_with(mount_path)
+
     def test__unmount_device_is_busy_error(self):
         def exec_runner(*ignore_args, **ignore_kwargs):
             raise exception.ProcessExecutionError(stderr='device is busy')
@@ -449,16 +469,29 @@ class LVMShareDriverTestCase(test.TestCase):
     def _get_mount_path(self, share):
         return os.path.join(CONF.lvm_share_export_root, share['name'])
 
-    def test__unmount_device(self):
+    @ddt.data(True, False)
+    def test__unmount_device_with_retry_busy_device(self, retry_busy_device):
+        execute_sideeffects = [
+            exception.ProcessExecutionError(stderr='device is busy'),
+            exception.ProcessExecutionError(stderr='target is busy'),
+            None, None
+        ] if retry_busy_device else [None, None]
         mount_path = self._get_mount_path(self.share)
         self._os.path.exists.return_value = True
-        self.mock_object(self._driver, '_execute')
-        self._driver._unmount_device(self.share)
-        self._driver._execute.assert_any_call('umount', '-f', mount_path,
-                                              run_as_root=True)
-        self._driver._execute.assert_any_call('rmdir', mount_path,
-                                              run_as_root=True)
+        self.mock_object(self._driver, '_execute', mock.Mock(
+            side_effect=execute_sideeffects))
+
+        self._driver._unmount_device(self.share,
+                                     retry_busy_device=retry_busy_device)
+
+        num_of_times_umount_is_called = 3 if retry_busy_device else 1
+
         self._os.path.exists.assert_called_with(mount_path)
+        self._driver._execute.assert_has_calls([
+            mock.call('umount', '-f', mount_path, run_as_root=True),
+        ] * num_of_times_umount_is_called + [
+            mock.call('rmdir', mount_path, run_as_root=True)
+        ])
 
     def test_extend_share(self):
         local_path = self._driver._get_local_path(self.share)
@@ -499,6 +532,7 @@ class LVMShareDriverTestCase(test.TestCase):
             'total_capacity_gb': 33,
             'free_capacity_gb': 22,
             'reserved_percentage': 0,
+            'reserved_snapshot_percentage': 0,
         }, ]
         self.mock_object(
             self._driver,
